<h1 align="center">ZaidPy</h1>
<p align="center">It's a Usefull Project for Developers ... It checkers Emails Found Or Not Found</p>

<p align="center"> • DevVlopered The Lib BY zaid</p>


## Installing :
```
pip install ZaidPy

```
## • Domains •

⌯ Gmail 

⌯ Hotmail 

⌯ Outlook

⌯ Yahoo 

⌯ mail.ru

⌯ Aol

